<?php
/*
Plugin Name: Covert Geo Targeter
Description: Simple to use plugin that lets you insert shortcodes to display your visitors city, state, country etc. anywhere on your blog. Using geo targeting will boost your CTR and conversions. <a href="http://covertgeotargeter.com/upgrade">Click here to upgrade to the Pro version.</a>
Version: 2.0
Author: IM Wealth Builders Ltd
Author URI: http://imwealthbuilders.com/newplugins

Copyright 2018  IM Wealth Builders

*/

define('IMWB_CGT_VERSION', '2.0');
define('IMWB_CGT_FOLDER', 'covertgeotargeter');
define('IMWB_CGT_PREFIX', 'imwb_');
define('IMWB_CGT_FILE', __FILE__ );

/**
 * This is where you add comments for your plugin class
 * @author John Merrick
 */
class IMWB_Covert_Geo_Targeter {
	/**
	 * This value will be used for
	 * - the gettext textdomain
	 * - the subfolder when adding scripts and styles
	 * - the handle for scripts and styles
	 * Please make sure that this value corresponds to the folder name where your plugin resides.
	 * @var string
	 */
	 var $plugin_name = "";
	 var $plugin_url = "";
	 var $update;
	 var $geolocation;
	 var $options = Array();

	/**
	 * The constructor is executed when the class is instatiated and the plugin gets loaded.
	 * @return void
	 */
	function __construct() {

	   $this->plugin_name = IMWB_CGT_PREFIX.IMWB_CGT_FOLDER;

   	// Hack to avoid firing on Admin Login or Registration page
   	if ( in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) )
   	   return;

   	$this->plugin_url = plugins_url(basename( dirname( __FILE__)));

      $this->options = $this->get_admin_options();

      if(is_admin()){
         // Get Update Information
      	$this->get_update_info();
      	add_action('admin_notices', array(&$this, 'admin_warnings'));
      	add_action('admin_menu', array(&$this,'init_admin_menu'));
//     		add_action('init', array(&$this, 'init_styles'), 20);
  		  	// add_action( 'admin_print_scripts-settings_page_'.$this->plugin_name.'-admin-menu', array(&$this, 'init_styles'));
      	// add_action( 'admin_print_scripts-settings_page_'.$this->plugin_name.'-admin-menu', array(&$this,'init_admin_scripts') );
      }
      else {
         $this->geolocation = $this->get_geo_location();

      	add_filter('the_title', array(&$this, 'populate_geo_location'), '1');
      	add_filter('widget_text', array(&$this, 'populate_geo_location'), '1');
      	add_filter('widget_title', array(&$this, 'populate_geo_location'), '1');
      	add_filter('wp_title', array(&$this, 'populate_geo_location'), '1');
      	add_filter('option_blogdescription', array(&$this, 'populate_geo_location'), '1');
      	add_filter('option_blogname', array(&$this, 'populate_geo_location'), '1');

      	add_shortcode( 'imwb_cgt_countryCode', array(&$this, 'countryCode_shortcode_handler') );
      	add_shortcode( 'imwb_cgt_countryName', array(&$this, 'countryName_shortcode_handler') );
      	add_shortcode( 'imwb_cgt_regionName', array(&$this, 'regionName_shortcode_handler') );
      	add_shortcode( 'imwb_cgt_cityName', array(&$this, 'cityName_shortcode_handler') );
      }
	}

	function admin_warnings() {

		 if(empty($this->options['api_key']) && !isset($_POST['submit']) ) {
				echo "<div id='update-nag' class='update-nag'><strong>Covert Geo Targeter is almost ready</strong> ".sprintf(__('You must <a href="%1$s">enter your API key</a> for it to work.'), "options-general.php?page=imwb_covertgeotargeter-admin-menu")."</div>";
			}
	}

	//Returns an array of admin options
	function get_admin_options() {
		$adminOptions = array('provider' => 'I',
		                      'api_key' => '',
		                      'def_ctycode' => '',
		                      'def_ctyname' => '',
		                      'def_regname' => '',
		                      'def_cityname'=>'');

		$devOptions = get_option($this->plugin_name."-AdminOptions");
		if (!empty($devOptions)) {
			foreach ($devOptions as $key => $option)
				$adminOptions[$key] = $option;
		}
		update_option($this->plugin_name."-AdminOptions", $adminOptions);
		return $adminOptions;
	}


   /**
    * Loading the Admin side javascripts
    * /scripts/admin_options_page.js from the plugin directory.
    * @return void
    */

   function init_admin_scripts() {
     // Only enqueue scripts on frontend.
   	 wp_enqueue_script('jquery');
     wp_enqueue_script('imwb_cgt_admin_options_script', $this->plugin_url.'/scripts/admin_options_page.js', array('jquery'), '1.1');
   	 wp_localize_script('imwb_cgt_admin_options_script', 'IMWB_CGT_Ajax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'nonce' => wp_create_nonce( 'imwb_cgt_clear_cookie_nonce' ), 'plugin_url' => $this->plugin_url, 'wp_root' => $this->get_wp_root_path() ) );
   }

	/**
	 * Loading the stylesheet for this plugin.
	 * @return void
	 */
	function init_admin_styles() {

   if(is_admin()) {
		   wp_enqueue_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/admin_options_page.css', array(), '1.1', 'all');
		}
	}

	/**
	 * Adds a new menu with the name "My Admin Menu" and let's anyone that
	 * can publish posts be able to use it.
	 * @return void
	 */
	function init_admin_menu() {

		// Add the menu page
		$hook_menu = add_menu_page( 'Covert Geo Targeter Admin Menu',
		    'Covert Geo Targeter',
		    'manage_options',
		    $this->plugin_name . '-admin-menu',
		    array(&$this, 'main_menu_page'),
		    'dashicons-location-alt');

      add_action( 'admin_print_styles-' . $hook_menu, array(&$this, 'init_admin_styles'));
      add_action( 'admin_print_scripts-' . $hook_menu, array(&$this, 'init_admin_scripts'));
	}
	/**
	 * This function will be executed when the admin page is to be loaded
	 * @return void
	 */
	function main_menu_page() {

		// Include the HTML from a separate file to keep the plugin class clean
		require "pages/admin_options_page.php";
	}


	function get_wp_root_path()
	{
	    $path = parse_url(get_bloginfo('wpurl'), PHP_URL_PATH);
	    if(!isset($path))
	       return '/';
	    else
	  	    return $path;
	}

	function get_update_info() {
      // Include Update Class
      require_once('DigitalGuard_IT_Updater_1_0.php');

      // Initialize Update Object
      $this->update = new DigitalGuard_IT_Updater_1_0('5234538F29CBE', IMWB_CGT_FILE, IMWB_CGT_FOLDER, 'plugin-update');
	}


	function populate_geo_location($content) {

	   $content = str_ireplace('[imwb_cgt_countryCode]',$this->countryCode_shortcode_handler(), $content);
  	   $content = str_ireplace('[imwb_cgt_countryName]',$this->countryName_shortcode_handler(), $content);
  	   $content = str_ireplace('[imwb_cgt_regionName]',$this->regionName_shortcode_handler(), $content);
  	   $content = str_ireplace('[imwb_cgt_cityName]',$this->cityName_shortcode_handler(), $content);

	   return $content;
	}

	function countryCode_shortcode_handler() {
	   if(empty($this->geolocation->countryCode))
	      return $this->options['def_ctycode'];

   	return $this->geolocation->countryCode;
	}

   function countryName_shortcode_handler() {
      if(empty($this->geolocation->countryName))
         return $this->options['def_ctyname'];

   	return ucwords(strtolower($this->geolocation->countryName));
   }

   function regionName_shortcode_handler() {
      if(empty($this->geolocation->regionName))
         return $this->options['def_regname'];

   	return ucwords(strtolower($this->geolocation->regionName));
   }

   function cityName_shortcode_handler() {
      if(empty($this->geolocation->cityName))
         return $this->options['def_cityname'];

   	return ucwords(strtolower($this->geolocation->cityName));
   }


	function get_geo_location(){

    if ( !empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
			$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
		} elseif ( !empty ( $_SERVER['HTTP_X_REAL_IP'] ) ) {
			$ip = $_SERVER['HTTP_X_REAL_IP'];
		} else {
			$ip = $_SERVER['REMOTE_ADDR'];
		}

      // Check if "cache" cookie is set
      if(isset($_COOKIE['imwb_cgt_loc'])) {
	      $result = unserialize(stripslashes(base64_decode($_COOKIE['imwb_cgt_loc'])));
         if($result->ipAddress == $ip && $result->provider == $this->options['provider'])
	         return $result;
	   }

      if($this->options['provider'] == 'I')
	       return $this->ipinfodb_get_geo_location($ip);
	    else
	       return $this->geoplugin_get_geo_location($ip);
	}

	function ipinfodb_get_geo_location($ip) {

	      if(empty($this->options['api_key']))
	         return false;

		    $answer = wp_remote_get("http://api.ipinfodb.com/v3/ip-city/?key=".$this->options['api_key']."&ip=$ip&format=json");

		    if(is_wp_error($answer) || 200 != $answer['response']['code'])
		    {
		    	//wp_die('Could not get Country information.','Covert Geo Targeter Error');
		    	// MIGHT WANT TO SET DEFAULTS.
		    	return false;
		    }

			$answer = json_decode($answer['body']);

			// Convert UK to GB (ISO Std is GB)
			if($answer->countryCode == 'UK')
			   $answer->countryCode = 'GB';

      	$result = new stdClass();
			$result->provider = "I";
			$result->ipAddress = $answer->ipAddress;
			$result->countryCode = $answer->countryCode;
			$result->countryName = $answer->countryName;
			$result->regionName = $answer->regionName == '-' ? '' : $answer->regionName;
			$result->cityName = $answer->cityName == '-' ? '' : $answer->cityName;

			setcookie('imwb_cgt_loc',base64_encode(serialize($result)),time()+60*60,COOKIEPATH);

		   return $result;
	}

   function geoplugin_get_geo_location($ip){

   	    $answer = wp_remote_get("http://www.geoplugin.net/php.gp?ip=$ip");

   	    if(is_wp_error($answer) || 200 != $answer['response']['code'])
   	    {
   	    	//wp_die('Could not get Country information.','Covert Geo Targeter Error');
   	    	// MIGHT WANT TO SET DEFAULTS.
   	    	return false;
   	    }

   		$answer = unserialize($answer['body']);

      	$result = new stdClass();
         $result->provider = "G";
         $result->ipAddress = $answer['geoplugin_request'];
         $result->countryCode = $answer['geoplugin_countryCode'];
         $result->countryName = $answer['geoplugin_countryName'];
         $result->regionName = $answer['geoplugin_regionName'];
         $result->cityName = $answer['geoplugin_city'];

   		setcookie('imwb_cgt_loc',base64_encode(serialize($result)),time()+60*60,COOKIEPATH);
   	    return $result;
   }
}

/**
 * Register the plugin
 */
function run_covert_geo_targeter() {
	$plugin = new IMWB_Covert_Geo_Targeter();
}
run_covert_geo_targeter();
